@@ -123,7 +123,7 @@ class NotionProcessor:
         with open(file_name, "w", encoding="utf8") as writeable:
             writeable.write(content)
 
-        parent_directory = str(file_name)[len(CONTENT_DIRECTORY) :]  # noqa
+        parent_directory = str(file_name)[len(self.content_root) :]  # noqa
 
         self.links.append(Link(parent_directory, name=page_title))
         return content
